@@ -5,18 +5,18 @@ use strict;
 use Devel::Examine::Subs;
 
 
-my $params = {
+my %params = (
                 file => 't/sample.data', 
-              };
+              );
 
-my $des = Devel::Examine::Subs->new($params);
+my $des = Devel::Examine::Subs->new(%params);
 
 my $all = $des->run({engine => 'all'});
 
 print "$_\n" for @$all;
 
-$all = $des->all({
+$all = $des->all(
                 file => '../t/sample.data', 
-});
+);
 
 print scalar(@$all) . "\n";
