@@ -1,8 +1,9 @@
 package Devel::Examine::Subs;
+use Devel::Trace::Subs qw(trace trace_dump); # injected by Devel::Trace::Subs
 use warnings;
 use strict;
 
-our $VERSION = '1.30';
+our $VERSION = '1.31';
 
 use Carp;
 use Data::Compare;
@@ -16,6 +17,7 @@ use Symbol;
 use Tie::File;
 
 sub new {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -31,6 +33,7 @@ sub new {
     return $self;
 }
 sub run {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -54,6 +57,7 @@ sub run {
     return $struct;
 }
 sub _run_directory {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -63,6 +67,7 @@ sub _run_directory {
     my $dir = $self->{params}{file};
 
     find({wanted => sub {
+            trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
             return if ! -f;
 
             my @extensions = @{$self->{params}{extensions}};
@@ -96,6 +101,7 @@ sub _run_directory {
     return \%struct;
 }
 sub _run_end {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $value = shift;
@@ -105,6 +111,7 @@ sub _run_end {
     return $self->{run_end};
 }
 sub _cache {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $file = shift if @_;
@@ -127,11 +134,13 @@ sub _cache {
     }
 }
 sub _cache_enabled {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     return $self->{params}{cache};
 }
 sub _cache_safe {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $value = shift;
@@ -141,12 +150,14 @@ sub _cache_safe {
     return $self->{cache_safe};
 }
 sub _params {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my %params = @_;
     return \%params;
 }
 sub _config {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -241,6 +252,7 @@ sub _config {
     }
 }
 sub _clean_config {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $config_vars = shift; # href of valid params
@@ -267,6 +279,7 @@ sub _clean_config {
     }
 }
 sub _clean_core_config {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     # deletes core phase info after each run
 
@@ -283,6 +296,7 @@ sub _clean_core_config {
     }
 }
 sub _file {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
 
     my $self = shift;
@@ -340,6 +354,7 @@ sub _file {
    return $self->{params}{file};
 }
 sub _core {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     
     my $self = shift;
 
@@ -433,6 +448,7 @@ sub _core {
     return $subs;
 }
 sub _subs {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     
     my $self = shift;
     
@@ -504,6 +520,7 @@ sub _subs {
     return \%subs;
 }
 sub _pre_proc {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -560,6 +577,7 @@ sub _pre_proc {
     return $cref;
 }
 sub _pre_filter {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -636,6 +654,7 @@ sub _pre_filter {
     return @pre_filters;
 }
 sub _engine {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -690,6 +709,7 @@ sub _engine {
     return $cref;
 }
 sub pre_procs {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Preprocessor";
@@ -703,6 +723,7 @@ sub pre_procs {
     return @pre_procs;
 }
 sub pre_filters {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Prefilter";
@@ -716,6 +737,7 @@ sub pre_filters {
     return @pre_filters;
 }
 sub engines {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Engine";
@@ -729,6 +751,7 @@ sub engines {
     return @engines;
 }
 sub has {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -739,6 +762,7 @@ sub has {
     $self->run($p);
 }
 sub missing {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -748,6 +772,7 @@ sub missing {
     $self->run($p);
 }
 sub all {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -757,6 +782,7 @@ sub all {
     $self->run($p);
 }
 sub lines {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -770,6 +796,7 @@ sub lines {
     $self->run($p);
 }
 sub module {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -785,6 +812,7 @@ sub module {
     $self->run($p);
 }
 sub objects {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -795,6 +823,7 @@ sub objects {
     $self->run($p);
 }
 sub search_replace {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -807,6 +836,7 @@ sub search_replace {
     $self->run($p);
 }
 sub inject {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     my $p = $self->_params(@_);
 
@@ -820,6 +850,7 @@ sub inject {
     $self->run($p);
 }
 sub remove {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -830,6 +861,7 @@ sub remove {
     $self->run($p);
 }
 sub inject_after {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -846,6 +878,7 @@ sub inject_after {
     $self->run($p);
 }
 sub add_functionality {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     
     my $self = shift;
     my $p = $self->_params(@_);
@@ -869,6 +902,7 @@ sub add_functionality {
 
     my %dt = (
             engine => sub {
+                        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
                         return $in_prod
                         ? $INC{'Devel/Examine/Subs/Engine.pm'}
                         : 'lib/Devel/Examine/Subs/Engine.pm';
@@ -910,6 +944,7 @@ sub add_functionality {
     push @TIE_file, @code;
 }
 sub valid_params {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
     return %{$self->{valid_params}};
@@ -1562,6 +1597,12 @@ will be executed based on their order in the array reference.
 
 =back
 
+=head1 DEBUGGING
+
+This module is equipped with the C<Devel::Trace::Subs> module.
+
+To enable trace debugging, set C<$ENV{DTS_ENABLE}> and C<$ENV{DES_TRACE}>
+environment variables to true values in the calling script.
 
 
 
