@@ -1,14 +1,16 @@
 package Devel::Examine::Subs::Preprocessor;
 
+use Devel::Trace::Subs qw(trace trace_dump); # injected by Devel::Trace::Subs
 use strict; 
 use warnings;
 
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.30';
+our $VERSION = '1.31';
 
 sub new {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -21,6 +23,7 @@ sub new {
 }
 
 sub _dt {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     my $self = shift;
 
@@ -35,6 +38,7 @@ sub _dt {
 }
 
 sub exists {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
     my $self = shift;
     my $string = shift;
 
@@ -47,8 +51,10 @@ sub exists {
 }
 
 sub module {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
+        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         no strict 'refs';
 
@@ -78,8 +84,10 @@ sub module {
 }
 
 sub inject {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
+        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
         my $p = shift;
         my $file = $p->{file};
@@ -129,13 +137,23 @@ sub inject {
 
             while (my ($i, $e) = each @file){
 
+                if ($e =~ /^\n/){
+                    push @new_file, "\n";
+                }
+
                 my $indent = '';
 
                 my $count = $i;
                 $count++;
 
-                if ($file[$count] && $file[$count] =~ /^(\s+)/){
-                    $indent = $1;
+                while ($count < @file){
+                    if ($file[$count] =~ /^(\s*)\S/){
+                        $indent = $1;
+                        last;
+                    }
+                    else {
+                        $count++;
+                    }
                 }
 
                 push @new_file, $e;
@@ -166,8 +184,10 @@ sub inject {
 }
 
 sub remove {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
     return sub {
+        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
         
         my $p = shift;
         my $file = $p->{file};        
